@@ -55,6 +55,7 @@ class Client:
         return len(self.bot.users)
 
     async def post_data(self):
+        print("POSTING")
         bot_id = str(self.bot.user.id)
         key = self.key
         servers = str(self.servers)
@@ -101,6 +102,7 @@ class Client:
         The internal loop used for automatically posting server/guild count stats
         """
         await self.bot.wait_until_ready()
+        print("Starting Posting")
         while not self.bot.is_closed():
             await self.post_data()
             await asyncio.sleep(3600)
